@@ -6,7 +6,7 @@ Usage (cli):
 
     $ arp | jc --arp
 
-    or
+or
 
     $ jc arp
 
@@ -15,11 +15,6 @@ Usage (module):
     import jc
     result = jc.parse('arp', arp_command_output)
 
-    or
-
-    import jc.parsers.arp
-    result = jc.parsers.arp.parse(arp_command_output)
-
 Schema:
 
     [
@@ -117,13 +112,14 @@ Examples:
       }
     ]
 """
+from typing import List, Dict, Any
 import jc.utils
 import jc.parsers.universal
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.8'
+    version = '1.11'
     description = '`arp` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -134,7 +130,7 @@ class info():
 __version__ = info.version
 
 
-def _process(proc_data):
+def _process(proc_data: List[Dict]) -> List[Dict]:
     """
     Final processing to conform to the schema.
 
@@ -146,13 +142,13 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema:
     """
+    int_list = {'expires'}
 
     # in BSD style, change name to null if it is a question mark
     for entry in proc_data:
         if 'name' in entry and entry['name'] == '?':
             entry['name'] = None
 
-        int_list = ['expires']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
@@ -160,7 +156,11 @@ def _process(proc_data):
     return proc_data
 
 
-def parse(data, raw=False, quiet=False):
+def parse(
+    data: str,
+    raw: bool = False,
+    quiet: bool = False
+) -> List[Dict]:
     """
     Main text parsing function
 
@@ -190,7 +190,7 @@ def parse(data, raw=False, quiet=False):
         if cleandata[0][-1] == ']':
             for line in cleandata:
                 splitline = line.split()
-                output_line = {
+                output_line: Dict[str, Any] = {
                     'name': splitline[0],
                     'address': splitline[1].lstrip('(').rstrip(')'),
                     'hwtype': splitline[-1].lstrip('[').rstrip(']'),
@@ -208,11 +208,6 @@ def parse(data, raw=False, quiet=False):
 
                 raw_output.append(output_line)
 
-            if raw:
-                return raw_output
-            else:
-                return _process(raw_output)
-
         # detect if linux style was used
         elif cleandata[0].startswith('Address'):
 
@@ -225,17 +220,25 @@ def parse(data, raw=False, quiet=False):
         # otherwise, try bsd style
         else:
             for line in cleandata:
-                line = line.split()
-                output_line = {
-                    'name': line[0],
-                    'address': line[1].lstrip('(').rstrip(')'),
-                    'hwtype': line[4].lstrip('[').rstrip(']'),
-                    'hwaddress': line[3],
-                    'iface': line[6],
-                }
+                splitline = line.split()
+                if '<incomplete>' not in splitline:
+                    output_line = {
+                        'name': splitline[0],
+                        'address': splitline[1].lstrip('(').rstrip(')'),
+                        'hwtype': splitline[4].lstrip('[').rstrip(']'),
+                        'hwaddress': splitline[3],
+                        'iface': splitline[6],
+                    }
+
+                else:
+                    output_line = {
+                        'name': splitline[0],
+                        'address': splitline[1].lstrip('(').rstrip(')'),
+                        'hwtype': None,
+                        'hwaddress': None,
+                        'iface': splitline[5],
+                    }
+
                 raw_output.append(output_line)
 
-    if raw:
-        return raw_output
-    else:
-        return _process(raw_output)
+    return raw_output if raw else _process(raw_output)
