@@ -4,7 +4,7 @@ Usage (cli):
 
     $ lsof | jc --lsof
 
-    or
+or
 
     $ jc lsof
 
@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('lsof', lsof_command_output)
 
-    or
-
-    import jc.parsers.lsof
-    result = jc.parsers.lsof.parse(lsof_command_output)
-
 Schema:
 
     [
@@ -125,7 +120,7 @@ import jc.parsers.universal
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.5'
+    version = '1.6'
     description = '`lsof` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -148,8 +143,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'pid', 'tid', 'size_off', 'node'}
+
     for entry in proc_data:
-        int_list = ['pid', 'tid', 'size_off', 'node']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
